| Title: | Easily Downloads a Gene Expression Dataset from a GEO Code and Retrieves the Gene Symbols of Its Probesets |
|---|---|
| Description: | A function that reads in the GEO code of a gene expression dataset, retrieves its data from GEO, (optionally) retrieves the gene symbols of the dataset, and returns a simple dataframe table containing all the data. Platforms available: GPL11532, GPL23126, GPL6244, GPL8300, GPL80, GPL96, GPL570, GPL571, GPL20115, GPL1293, GPL6102, GPL6104, GPL6883, GPL6884, GPL13497, GPL14550, GPL17077, GPL6480. GEO: Gene Expression Omnibus. ID: identifier code. The GEO datasets are downloaded from the URL <https://ftp.ncbi.nlm.nih.gov/geo/series/>. More information can be found in the following manuscript: Davide Chicco, "geneExpressionFromGEO: an R package to facilitate data reading from Gene Expression Omnibus (GEO)". Microarray Data Analysis, Methods in Molecular Biology, volume 2401, chapter 12, pages 187-194, Springer Protocols, 2021, <doi:10.1007/978-1-0716-1839-4_12>. |
| Authors: | Davide Chicco [aut, cre] (ORCID: <https://orcid.org/0000-0001-9655-7142>) |
| Maintainer: | Davide Chicco <[email protected]> |
| License: | GPL-3 |
| Version: | 1.3 |
| Built: | 2026-05-08 07:35:53 UTC |
| Source: | https://github.com/cran/geneExpressionFromGEO |
Function that returns numeric values with 2 decimal numbers.
dec_two(x)dec_two(x)
x |
input numeric value with N decimal numbers. |
a numeric value with 2 decimal numbers.
aaa <- dec_two(8.31232)aaa <- dec_two(8.31232)
Function that reads in the GEO code of a dataset, and returns the complete gene expression dataframe by printing its features (if requested).
getDatasetFeaturesFromGEOcode(GSE_code, verbose = FALSE)getDatasetFeaturesFromGEOcode(GSE_code, verbose = FALSE)
GSE_code |
the GEO code of a dataset. |
verbose |
a boolean flag stating if helping messages should be printed or not |
a complete gene expression dataset.
# geneExpressionDF <- getDatasetFeaturesFromGEOcode("GSE23906", FALSE) geneExpressionDF <- getDatasetFeaturesFromGEOcode(NULL, FALSE)# geneExpressionDF <- getDatasetFeaturesFromGEOcode("GSE23906", FALSE) geneExpressionDF <- getDatasetFeaturesFromGEOcode(NULL, FALSE)
Function that reads in the GEO code of a dataset, and returns the gene expression dataframe.
getGeneExpressionFromGEO(datasetGeoCode, retrieveGeneSymbols, verbose = FALSE)getGeneExpressionFromGEO(datasetGeoCode, retrieveGeneSymbols, verbose = FALSE)
datasetGeoCode |
the GEO code of a dataset. |
retrieveGeneSymbols |
a boolean flag stating if the function should retrieve the gene symbols or not. |
verbose |
a boolean flag stating if helping messages should be printed or not |
a gene expression dataset.
# geneExpressionDF1 <- getGeneExpressionFromGEO("GSE23906", FALSE, FALSE) geneExpressionDF1 <- getGeneExpressionFromGEO(NULL, FALSE, FALSE)# geneExpressionDF1 <- getGeneExpressionFromGEO("GSE23906", FALSE, FALSE) geneExpressionDF1 <- getGeneExpressionFromGEO(NULL, FALSE, FALSE)
Function that reads in a URL to check and verifies if it exists (function written by Janko Thyson @rappster and taken from https://stackoverflow.com/a/12195574 )
readUrl(url)readUrl(url)
url |
the URL of a webpage |
the output of a webpage verification check
y <- readUrl("http://stat.ethz.ch/R-manual/R-devel/library/base/html/connections.html")y <- readUrl("http://stat.ethz.ch/R-manual/R-devel/library/base/html/connections.html")